@@ -192,8 +192,8 @@ class MongoODMBase(MongODMBaseModel):
             return e
         raise NotFound
 
-    def after_get_many_hook(self):
-        self.after_find()
+    async def after_get_many_hook(self):
+        await self.after_find()
         return self
 
     @classmethod
@@ -201,19 +201,19 @@ class MongoODMBase(MongODMBaseModel):
         cls,
         page: int = 1,
         per_page: int = 20,
-        selector_z: dict = None,
+        selector: dict = None,
         **kwargs,
     ) -> list:  # -> List[Self]
-        if selector_z is None:
-            selector_z = kwargs
-        selector_z = cls.replace_str_with_object_id(selector_z)
+        if selector is None:
+            selector = kwargs
+        selector = cls.replace_str_with_object_id(selector)
         items = await config['database_connection'][config['database_name']][cls.__collection_name__]\
-            .find(cls._get_fetch_filter(selector_z))\
+            .find(cls._get_fetch_filter(selector))\
             .skip((page - 1) * per_page)\
             .limit(per_page)\
             .to_list(length=None)
 
-        return [cls(**item).after_get_many_hook() for item in items]
+        return [await cls(**item).after_get_many_hook() for item in items]
 
     def set_attributes(self, **kwargs):
         for key, value in kwargs.items():
